==> haskell-mime-mail-0.5.1-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-AUilr8rnNJxBfU9zQru655
key:                  mime-mail-0.5.1-AUilr8rnNJxBfU9zQru655
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  60236b7d869b5711ef2119cbd734064c
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-AUilr8rnNJxBfU9zQru655
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-6q4Jlow4UI5PGuVolnxGn
    blaze-builder-0.4.4-LwgH2lQg9UbBZKk19Yi6xR bytestring-0.11.5.3
    filepath-1.4.2.2 process-1.6.18.0
    random-1.2.1.3-2ZgWYD0ujk9C5rWAN16PoW text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-mail-0.5.1-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-DVXmBrNsTMS1LoMbqMR7ID
key:                  mime-mail-0.5.1-DVXmBrNsTMS1LoMbqMR7ID
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  8e0001ae11bb81755331e7bc6d567780
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-DVXmBrNsTMS1LoMbqMR7ID
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-AbhqXNvtZOJLR3Ub6lZ1hd
    blaze-builder-0.4.4-B9xPgnx2s5zBBpIZbyzMq2 bytestring-0.11.5.3
    filepath-1.4.2.2 process-1.6.18.0
    random-1.2.1.3-6i9JKgFPfeq3EPTeuIde26 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
